@@ -40,6 +40,10 @@ _PLATFORM_ID_RE = re.compile(
 # use uppercase names for case insensitive match
 EXTERNAL_PROJECTS = ("ROOT",)
 
+# list of fixed paths for specific projects, used to bypass
+# the lookup for nightly builds
+forced_paths = {}
+
 
 def platform_sort_key(platform):
     """
@@ -203,36 +207,47 @@ def findProject(name, version, platform, allow_empty_version=False):
         allow_empty_version,
     )
 
+    if name in forced_paths:
+        d = os.path.normpath(os.path.join(forced_paths[name], "InstallArea", platform))
+        if os.path.exists(d):
+            # name is None when using --path-to-project
+            log.debug("using %s for %s", d, name or "main project")
+            return d
+        else:
+            raise MissingProjectError(name, version, platform, forced_paths[name])
+
+    # list of version strings to try
+    versions = [version]
+
     if re.match(r"^\d+\.\d+(\.\d+)*$", version):
         # If we are requested to find a X.Y[.Z] version (new style CMake config)
-        # we have to look for directories with vXrY[pZ]
+        # we have to look also for directories with vXrY[pZ]
         parts = version.split(".")
         if len(parts) == 2:
-            version = "v{}r{}".format(*parts)
+            versions.append("v{}r{}".format(*parts))
         elif len(parts) == 3:
-            version = "v{}r{}p{}".format(*parts)
+            versions.append("v{}r{}p{}".format(*parts))
         else:
             pass  # we have a convention only for 2 or 3 parts versions
 
-    if name:
-        # standard project suffixes
-        suffixes = [
-            "{0}_{1}".format(name, version),
-            os.path.join(name.upper(), "{0}_{1}".format(name.upper(), version)),
-            os.path.join(name.upper(), version),
-        ]
-        # special case: for the 'latest' version we allow the plain name
-        if allow_empty_version:
-            suffixes.insert(0, name)
-    else:
-        # path to project used, no need for suffixes
-        suffixes = [os.curdir]
+    # standard project suffixes
+    suffixes = []
+    for v in versions:
+        suffixes.extend(
+            [
+                "{0}_{1}".format(name, v),
+                os.path.join(name.upper(), "{0}_{1}".format(name.upper(), v)),
+                os.path.join(name.upper(), v),
+            ]
+        )
+
+    # special case: for the 'latest' version we allow the plain name
+    if allow_empty_version:
+        suffixes.insert(0, name)
 
-    # if project name is None, version is the path to the top level directory
-    # of the project
     for d in [
         os.path.normpath(os.path.join(b, s, bindir))
-        for b in (path if name else [version])
+        for b in path
         for s in suffixes
         for bindir in (os.path.join("InstallArea", platform), os.curdir)
     ]:
@@ -257,7 +272,7 @@ def findNightlyDir(slot, build_id, nightly_bases):
     # log.debug('looking for slot %s %s', slot, build_id)
     for slot_dir in [
         os.path.join(nightly_base, slot_id, build_id)
-        for slot_id in (slot, "lhcb-" + slot)
+        for slot_id in (slot, "lhcb-" + slot, "nightly/" + slot, "nightly/lhcb-" + slot)
         for nightly_base in nightly_bases
     ]:
         if os.path.isdir(slot_dir):
