@@ -619,3 +619,143 @@ def test_incompatibility_report():
         assert re.search(
             r"dirac_platform: [^-]+-{}".format(os_id()), err.output.decode()
         )
+
+
+def test_path_to_project():
+    try:
+        from unittest.mock import patch
+    except ImportError:
+        raise SkipTest()  # only run on Python3
+
+    from LbEnv.ProjectEnv import path
+    from LbEnv.ProjectEnv.script import LbRun
+    import LbEnv.ProjectEnv.lookup
+
+    LbEnv.ProjectEnv.lookup.findProject.cache_clear()
+
+    bk_path = list(path)
+    path[:] = []
+
+    platform = "x86_64_v2-centos7-gcc11-opt"
+
+    data = {
+        "MyProject_v1r1/InstallArea/{}/manifest.xml".format(
+            platform
+        ): '<?xml version="1.0" encoding="UTF-8"?><manifest><project name="MyProject" version="1.1" /></manifest>',
+        "MyProject_v1r1/InstallArea/{}/MyProject.xenv".format(
+            platform
+        ): '<?xml version="1.0" encoding="UTF-8"?><env:config xmlns:env="EnvSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="EnvSchema EnvSchema.xsd "></env:config>',
+    }
+
+    with TempDir(data) as tmp:
+        with patch.dict("os.environ", {"CMAKE_PREFIX_PATH": tmp}):
+            with patch(
+                "sys.argv",
+                [
+                    "lb-run",
+                    "--force-platform",
+                    "--platform",
+                    platform,
+                    "--path-to-project",
+                    tmp + "/MyProject_v1r1",
+                ],
+            ):
+                run = LbRun()
+                run._makeEnv()
+                assert run.env["MYPROJECT_PROJECT_ROOT"] == (tmp + "/MyProject_v1r1")
+
+    path[:] = bk_path
+
+
+def test_cmake_version_lookup_to_vXrY():
+    try:
+        from unittest.mock import patch
+    except ImportError:
+        raise SkipTest()  # only run on Python3
+
+    from LbEnv.ProjectEnv import path
+    from LbEnv.ProjectEnv.script import LbRun
+    import LbEnv.ProjectEnv.lookup
+
+    LbEnv.ProjectEnv.lookup.findProject.cache_clear()
+
+    bk_path = list(path)
+    path[:] = []
+
+    platform = "x86_64_v2-centos7-gcc11-opt"
+
+    data = {
+        "MyProject_v1r1/InstallArea/{}/manifest.xml".format(
+            platform
+        ): '<?xml version="1.0" encoding="UTF-8"?><manifest><project name="MyProject" version="1.1" /></manifest>',
+        "MyProject_v1r1/InstallArea/{}/MyProject.xenv".format(
+            platform
+        ): '<?xml version="1.0" encoding="UTF-8"?><env:config xmlns:env="EnvSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="EnvSchema EnvSchema.xsd "></env:config>',
+    }
+
+    with TempDir(data) as tmp:
+        with patch.dict("os.environ", {"CMAKE_PREFIX_PATH": tmp}):
+            with patch(
+                "sys.argv",
+                [
+                    "lb-run",
+                    "--force-platform",
+                    "--platform",
+                    platform,
+                    "--dev-dir",
+                    tmp,
+                    "MyProject/1.1",
+                ],
+            ):
+                run = LbRun()
+                run._makeEnv()
+                assert run.env["MYPROJECT_PROJECT_ROOT"] == (tmp + "/MyProject_v1r1")
+
+    path[:] = bk_path
+
+
+def test_cmake_version_lookup_to_cmake_version():
+    try:
+        from unittest.mock import patch
+    except ImportError:
+        raise SkipTest()  # only run on Python3
+
+    from LbEnv.ProjectEnv import path
+    from LbEnv.ProjectEnv.script import LbRun
+    import LbEnv.ProjectEnv.lookup
+
+    LbEnv.ProjectEnv.lookup.findProject.cache_clear()
+
+    bk_path = list(path)
+    path[:] = []
+
+    platform = "x86_64_v2-centos7-gcc11-opt"
+
+    data = {
+        "MyProject_1.1/InstallArea/{}/manifest.xml".format(
+            platform
+        ): '<?xml version="1.0" encoding="UTF-8"?><manifest><project name="MyProject" version="1.1" /></manifest>',
+        "MyProject_1.1/InstallArea/{}/MyProject.xenv".format(
+            platform
+        ): '<?xml version="1.0" encoding="UTF-8"?><env:config xmlns:env="EnvSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="EnvSchema EnvSchema.xsd "></env:config>',
+    }
+
+    with TempDir(data) as tmp:
+        with patch.dict("os.environ", {"CMAKE_PREFIX_PATH": tmp}):
+            with patch(
+                "sys.argv",
+                [
+                    "lb-run",
+                    "--force-platform",
+                    "--platform",
+                    platform,
+                    "--dev-dir",
+                    tmp,
+                    "MyProject/1.1",
+                ],
+            ):
+                run = LbRun()
+                run._makeEnv()
+                assert run.env["MYPROJECT_PROJECT_ROOT"] == (tmp + "/MyProject_1.1")
+
+    path[:] = bk_path
